@@ -166,6 +166,7 @@ bool AdPlugXMMS::read_tag (const char * filename, VFSFile & file, Tuple & tuple,
   tuple.set_str (Tuple::Codec, p->gettype().c_str());
   tuple.set_str (Tuple::Quality, _("sequenced"));
   tuple.set_int (Tuple::Length, p->songlength (plr.subsong));
+  tuple.set_int (Tuple::Channels, 2);
   delete p;
 
   return true;
@@ -349,7 +350,7 @@ const PreferencesWidget AdPlugXMMS::widgets[] = {
   WidgetCombo (N_("OPL Emulator:"),
     WidgetInt (CFG_ID, "Emulator"),
     {{plugin_combo}}),
-  WidgetSpin (N_("Sample rate"),
+  WidgetSpin (N_("Sample rate:"),
     WidgetInt (CFG_ID, "Frequency"), {8000, 192000, 50, N_("Hz")}),
   WidgetLabel (N_("<b>Miscellaneous</b>")),
   WidgetCheck (N_("Repeat song in endless loop"),
