@@ -37,7 +37,8 @@ public:
         N_("AOSD (On-Screen Display)"),
         PACKAGE,
         about,
-        & prefs
+        & prefs,
+        PluginGLibOnly
     };
 
     constexpr AOSD () : GeneralPlugin (info, false) {}
