@@ -22,9 +22,11 @@
 
 #include <gtk/gtk.h>
 
+#define AUD_GLIB_INTEGRATION
 #include <libaudcore/i18n.h>
 #include <libaudcore/index.h>
 #include <libaudcore/preferences.h>
+#include <libaudgui/gtk-compat.h>
 
 #include "aosd.h"
 #include "aosd_style.h"
@@ -32,7 +34,32 @@
 #include "aosd_cfg.h"
 #include "aosd_osd.h"
 
+#ifdef USE_GTK3
+static void chooser_get_aosd_color (GtkColorChooser * chooser, aosd_color_t * color)
+{
+  GdkRGBA rgba;
+  gtk_color_chooser_get_rgba (chooser, & rgba);
 
+  color->red = rint (rgba.red * 65535.0);
+  color->green = rint (rgba.green * 65535.0);
+  color->blue = rint (rgba.blue * 65535.0);
+  color->alpha = rint (rgba.alpha * 65535.0);
+}
+
+
+static void chooser_set_aosd_color (GtkColorChooser * chooser, const aosd_color_t * color)
+{
+  GdkRGBA rgba = {
+      color->red / 65535.0,
+      color->green / 65535.0,
+      color->blue / 65535.0,
+      color->alpha / 65535.0
+  };
+
+  gtk_color_chooser_set_use_alpha (chooser, true);
+  gtk_color_chooser_set_rgba (chooser, & rgba);
+}
+#else
 static void chooser_get_aosd_color (GtkColorButton * chooser, aosd_color_t * color)
 {
   GdkColor gdk_color;
@@ -53,6 +80,7 @@ static void chooser_set_aosd_color (GtkColorButton * chooser, const aosd_color_t
   gtk_color_button_set_use_alpha (chooser, true);
   gtk_color_button_set_alpha (chooser, color->alpha);
 }
+#endif
 
 
 /*************************************************************/
@@ -80,17 +108,26 @@ aosd_callback_list_run ( aosd_cfg_t * cfg )
 
 static gboolean
 aosd_cb_configure_position_expose ( GtkWidget * darea ,
+#ifdef USE_GTK3
+                                    cairo_t * cr ,
+#else
                                     GdkEventExpose * event ,
+#endif
                                     void * coord_gp )
 {
   int coord = GPOINTER_TO_INT(coord_gp);
 
+#ifdef USE_GTK3
+  cairo_set_source_rgb ( cr , 0 , 0 , 0 );
+  cairo_rectangle ( cr , (coord % 3) * 10 , (coord / 3) * 16 , 20 , 8 );
+  cairo_fill ( cr );
+#else
   cairo_t * cr = gdk_cairo_create (gtk_widget_get_window (darea));
   cairo_set_source_rgb ( cr , 0 , 0 , 0 );
   cairo_rectangle ( cr , (coord % 3) * 10 , (coord / 3) * 16 , 20 , 8 );
   cairo_fill ( cr );
   cairo_destroy (cr);
-
+#endif
   return false;
 }
 
@@ -153,19 +190,24 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
   GtkWidget *pos_multimon_frame, *pos_multimon_hbox;
   GtkWidget *pos_multimon_label;
   GtkWidget *pos_multimon_combobox;
-  int monitors_num = gdk_screen_get_n_monitors( gdk_screen_get_default() );
   int i = 0;
 
-  pos_vbox = gtk_vbox_new( false , 4 );
+#ifdef USE_GTK3
+  int monitors_num = gdk_display_get_n_monitors ( gdk_display_get_default() );
+#else
+  int monitors_num = gdk_screen_get_n_monitors( gdk_screen_get_default() );
+#endif
+
+  pos_vbox = audgui_vbox_new( 4 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_vbox) , 6 );
 
   pos_placement_frame = gtk_frame_new( _("Placement") );
-  pos_placement_hbox = gtk_hbox_new( false , 0 );
+  pos_placement_hbox = audgui_hbox_new( 0 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_placement_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(pos_placement_frame) , pos_placement_hbox );
   gtk_box_pack_start( GTK_BOX(pos_vbox) , pos_placement_frame , false , false , 0 );
 
-  pos_placement_grid = gtk_table_new (0, 0, false);
+  pos_placement_grid = audgui_grid_new();
   for ( i = 0 ; i < 9 ; i++ )
   {
     if ( i == 0 )
@@ -176,10 +218,14 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
     pos_placement_bt_darea[i] = gtk_drawing_area_new();
     gtk_widget_set_size_request( pos_placement_bt_darea[i] , 40 , 40 );
     gtk_container_add( GTK_CONTAINER(pos_placement_bt[i]) , pos_placement_bt_darea[i] );
-    g_signal_connect( G_OBJECT(pos_placement_bt_darea[i]) , "expose-event" ,
+    g_signal_connect( G_OBJECT(pos_placement_bt_darea[i]) , AUDGUI_DRAW_SIGNAL ,
                       G_CALLBACK(aosd_cb_configure_position_expose) , GINT_TO_POINTER(i) );
+#ifdef USE_GTK3
+    gtk_grid_attach( GTK_GRID(pos_placement_grid) , pos_placement_bt[i] , (i % 3) , (i / 3) , 1 , 1 );
+#else
     gtk_table_attach_defaults( GTK_TABLE(pos_placement_grid) , pos_placement_bt[i] ,
                                (i % 3) , (i % 3) + 1 , (i / 3) , (i / 3) + 1 );
+#endif
     g_object_set_data( G_OBJECT(pos_placement_bt[i]) , "value" , GINT_TO_POINTER(i+1) );
     if ( cfg->position.placement == (i+1) )
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(pos_placement_bt[i]) , true );
@@ -187,38 +233,53 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
   gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_placement_grid , false , false , 0 );
   aosd_cb_list.append( pos_placement_grid , aosd_cb_configure_position_placement_commit );
 
-  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , gtk_vseparator_new() , false , false , 6 );
+  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , audgui_separator_new( GTK_ORIENTATION_VERTICAL ) , false , false , 6 );
 
-  pos_offset_grid = gtk_table_new (0, 0, false);
-  gtk_table_set_row_spacings( GTK_TABLE(pos_offset_grid) , 4 );
-  gtk_table_set_col_spacings( GTK_TABLE(pos_offset_grid) , 4 );
+  pos_offset_grid = audgui_grid_new();
+  audgui_grid_set_row_spacing( pos_offset_grid , 4 );
+  audgui_grid_set_column_spacing( pos_offset_grid , 4 );
   pos_offset_x_label = gtk_label_new( _( "Relative X offset:" ) );
-  gtk_misc_set_alignment( GTK_MISC(pos_offset_x_label) , 0 , 0.5 );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_x_label , 0 , 1 , 0 , 1 );
   pos_offset_x_spinbt = gtk_spin_button_new_with_range( -9999 , 9999 , 1 );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(pos_offset_x_spinbt) , cfg->position.offset_x );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_x_spinbt , 1 , 2 , 0 , 1 );
   g_object_set_data( G_OBJECT(pos_offset_grid) , "offx" , pos_offset_x_spinbt );
   pos_offset_y_label = gtk_label_new( _( "Relative Y offset:" ) );
-  gtk_misc_set_alignment( GTK_MISC(pos_offset_y_label) , 0 , 0.5 );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_y_label , 0 , 1 , 1 , 2 );
   pos_offset_y_spinbt = gtk_spin_button_new_with_range( -9999 , 9999 , 1 );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(pos_offset_y_spinbt) , cfg->position.offset_y );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_y_spinbt , 1 , 2 , 1 , 2 );
   g_object_set_data( G_OBJECT(pos_offset_grid) , "offy" , pos_offset_y_spinbt );
   pos_maxsize_width_label = gtk_label_new( _("Max OSD width:") );
-  gtk_misc_set_alignment( GTK_MISC(pos_maxsize_width_label) , 0 , 0.5 );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_maxsize_width_label , 0 , 1 , 2 , 3 );
   pos_maxsize_width_spinbt = gtk_spin_button_new_with_range( 0 , 99999 , 1 );
   g_object_set_data( G_OBJECT(pos_offset_grid) , "maxsize_width" , pos_maxsize_width_spinbt );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(pos_maxsize_width_spinbt) , cfg->position.maxsize_width );
-  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_maxsize_width_spinbt , 1 , 2 , 2 , 3 );
   gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_offset_grid , false , false , 0 );
   aosd_cb_list.append( pos_offset_grid , aosd_cb_configure_position_offset_commit );
   aosd_cb_list.append( pos_offset_grid , aosd_cb_configure_position_maxsize_commit );
 
+#ifdef USE_GTK3
+  gtk_widget_set_halign( pos_offset_x_label , GTK_ALIGN_START );
+  gtk_widget_set_halign( pos_offset_y_label , GTK_ALIGN_START );
+  gtk_widget_set_halign( pos_maxsize_width_label , GTK_ALIGN_START );
+
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_offset_x_label , 0 , 0 , 1 , 1 );
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_offset_x_spinbt , 1 , 0 , 1 , 1 );
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_offset_y_label , 0 , 1 , 1 , 1 );
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_offset_y_spinbt , 1 , 1 , 1 , 1 );
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_maxsize_width_label , 0 , 2 , 1 , 1 );
+  gtk_grid_attach( GTK_GRID(pos_offset_grid) , pos_maxsize_width_spinbt , 1 , 2 , 1 , 1 );
+#else
+  gtk_misc_set_alignment( GTK_MISC(pos_offset_x_label) , 0 , 0.5 );
+  gtk_misc_set_alignment( GTK_MISC(pos_offset_y_label) , 0 , 0.5 );
+  gtk_misc_set_alignment( GTK_MISC(pos_maxsize_width_label) , 0 , 0.5 );
+
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_x_label , 0 , 1 , 0 , 1 );
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_x_spinbt , 1 , 2 , 0 , 1 );
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_y_label , 0 , 1 , 1 , 2 );
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_offset_y_spinbt , 1 , 2 , 1 , 2 );
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_maxsize_width_label , 0 , 1 , 2 , 3 );
+  gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_maxsize_width_spinbt , 1 , 2 , 2 , 3 );
+#endif
+
   pos_multimon_frame = gtk_frame_new( _("Multi-Monitor options") );
-  pos_multimon_hbox = gtk_hbox_new( false , 4 );
+  pos_multimon_hbox = audgui_hbox_new( 4 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_multimon_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(pos_multimon_frame), pos_multimon_hbox );
   pos_multimon_label = gtk_label_new( _("Display OSD using:") );
@@ -241,10 +302,10 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
 
 
 static GtkWidget *
-aosd_ui_configure_animation_timing ( char * label_string )
+aosd_ui_configure_animation_timing ( const char * label_string )
 {
   GtkWidget *hbox, *desc_label, *spinbt;
-  hbox = gtk_hbox_new( false , 4 );
+  hbox = audgui_hbox_new( 4 );
   desc_label = gtk_label_new( label_string );
   spinbt = gtk_spin_button_new_with_range( 0 , 99999 , 1 );
   gtk_box_pack_start( GTK_BOX(hbox) , desc_label , false , false , 0 );
@@ -274,10 +335,10 @@ aosd_ui_configure_animation ( aosd_cfg_t * cfg )
   GtkWidget *ani_timing_fadein_widget, *ani_timing_fadeout_widget, *ani_timing_stay_widget;
   GtkSizeGroup *sizegroup;
 
-  ani_vbox = gtk_vbox_new( false , 0 );
+  ani_vbox = audgui_vbox_new( 0 );
   gtk_container_set_border_width( GTK_CONTAINER(ani_vbox) , 6 );
 
-  ani_timing_hbox = gtk_hbox_new( false , 0 );
+  ani_timing_hbox = audgui_hbox_new( 0 );
   ani_timing_frame = gtk_frame_new( _("Timing (ms)") );
   gtk_container_set_border_width( GTK_CONTAINER(ani_timing_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(ani_timing_frame) , ani_timing_hbox );
@@ -287,12 +348,12 @@ aosd_ui_configure_animation ( aosd_cfg_t * cfg )
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_stay_widget),"spinbt")) , cfg->animation.timing_display );
   gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_stay_widget , true , true , 0 );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , false , false , 4 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , audgui_separator_new( GTK_ORIENTATION_VERTICAL ) , false , false , 4 );
   ani_timing_fadein_widget = aosd_ui_configure_animation_timing( _("Fade in:") );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_fadein_widget),"spinbt")) , cfg->animation.timing_fadein );
   gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_fadein_widget , true , true , 0 );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , false , false , 4 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , audgui_separator_new( GTK_ORIENTATION_VERTICAL ) , false , false , 4 );
   ani_timing_fadeout_widget = aosd_ui_configure_animation_timing( _("Fade out:") );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_fadeout_widget),"spinbt")) , cfg->animation.timing_fadeout );
@@ -324,6 +385,26 @@ aosd_cb_configure_text_font_shadow_toggle ( GtkToggleButton * shadow_togglebt ,
 }
 
 
+#ifdef USE_GTK3
+static void
+aosd_cb_configure_text_font_commit ( GtkWidget * fontbt , aosd_cfg_t * cfg )
+{
+  int fontnum = GPOINTER_TO_INT(g_object_get_data( G_OBJECT(fontbt) , "fontnum" ));
+  GtkColorChooser * chooser;
+
+  CharPtr font_name (gtk_font_chooser_get_font (GTK_FONT_CHOOSER (fontbt)));
+  cfg->text.fonts_name[fontnum] = String (font_name);
+
+  cfg->text.fonts_draw_shadow[fontnum] = gtk_toggle_button_get_active(
+    GTK_TOGGLE_BUTTON(g_object_get_data(G_OBJECT(fontbt),"use_shadow")) );
+
+  chooser = (GtkColorChooser *) g_object_get_data ((GObject *) fontbt, "color");
+  chooser_get_aosd_color (chooser, & cfg->text.fonts_color[fontnum]);
+
+  chooser = (GtkColorChooser *) g_object_get_data ((GObject *) fontbt, "shadow_color");
+  chooser_get_aosd_color (chooser, & cfg->text.fonts_shadow_color[fontnum]);
+}
+#else
 static void
 aosd_cb_configure_text_font_commit ( GtkWidget * fontbt , aosd_cfg_t * cfg )
 {
@@ -342,6 +423,7 @@ aosd_cb_configure_text_font_commit ( GtkWidget * fontbt , aosd_cfg_t * cfg )
   chooser = (GtkColorButton *) g_object_get_data ((GObject *) fontbt, "shadow_color");
   chooser_get_aosd_color (chooser, & cfg->text.fonts_shadow_color[fontnum]);
 }
+#endif
 
 
 static GtkWidget *
@@ -354,14 +436,14 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
   GtkWidget *tex_font_shadow_colorbt[3];
   int i = 0;
 
-  tex_vbox = gtk_vbox_new( false , 4 );
+  tex_vbox = audgui_vbox_new( 4 );
   gtk_container_set_border_width( GTK_CONTAINER(tex_vbox) , 6 );
 
   tex_font_frame = gtk_frame_new( _("Fonts") );
-  tex_font_grid = gtk_table_new (0, 0, false);
+  tex_font_grid = audgui_grid_new();
   gtk_container_set_border_width( GTK_CONTAINER(tex_font_grid) , 6 );
-  gtk_table_set_row_spacings( GTK_TABLE(tex_font_grid) , 4 );
-  gtk_table_set_col_spacings( GTK_TABLE(tex_font_grid) , 4 );
+  audgui_grid_set_row_spacing( tex_font_grid , 4 );
+  audgui_grid_set_column_spacing( tex_font_grid , 4 );
   for ( i = 0 ; i < AOSD_TEXT_FONTS_NUM ; i++ )
   {
     char *label_str = g_strdup_printf( _("Font %i:") , i+1 );
@@ -372,18 +454,19 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
     gtk_font_button_set_show_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , true );
     gtk_font_button_set_use_font( GTK_FONT_BUTTON(tex_font_fontbt[i]) , false );
     gtk_font_button_set_use_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , false );
+
+#ifdef USE_GTK3
+    gtk_font_chooser_set_font( GTK_FONT_CHOOSER(tex_font_fontbt[i]) , cfg->text.fonts_name[i] );
+#else
     gtk_font_button_set_font_name( GTK_FONT_BUTTON(tex_font_fontbt[i]) , cfg->text.fonts_name[i] );
+#endif
 
     tex_font_colorbt[i] = gtk_color_button_new ();
-    chooser_set_aosd_color ((GtkColorButton *) tex_font_colorbt[i],
-     & cfg->text.fonts_color[i]);
 
     tex_font_shadow_togglebt[i] = gtk_toggle_button_new_with_label( _("Shadow") );
     gtk_toggle_button_set_mode( GTK_TOGGLE_BUTTON(tex_font_shadow_togglebt[i]) , false );
 
     tex_font_shadow_colorbt[i] = gtk_color_button_new ();
-    chooser_set_aosd_color ((GtkColorButton *) tex_font_shadow_colorbt[i],
-     & cfg->text.fonts_shadow_color[i]);
 
     gtk_widget_set_sensitive( tex_font_shadow_colorbt[i] , false );
     g_signal_connect( G_OBJECT(tex_font_shadow_togglebt[i]) , "toggled" ,
@@ -391,11 +474,27 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
                       tex_font_shadow_colorbt[i] );
     gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(tex_font_shadow_togglebt[i]) ,
       cfg->text.fonts_draw_shadow[i] );
+
+#ifdef USE_GTK3
+    chooser_set_aosd_color( GTK_COLOR_CHOOSER(tex_font_colorbt[i]) , &cfg->text.fonts_color[i] );
+    chooser_set_aosd_color( GTK_COLOR_CHOOSER(tex_font_shadow_colorbt[i]) , &cfg->text.fonts_shadow_color[i] );
+
+    gtk_grid_attach( GTK_GRID(tex_font_grid) , tex_font_label[i] , 0 , 0 , 1 , 1 );
+    gtk_grid_attach( GTK_GRID(tex_font_grid) , tex_font_fontbt[i] , 1 , 0 , 1 , 1 );
+    gtk_grid_attach( GTK_GRID(tex_font_grid) , tex_font_colorbt[i] , 2 , 0 , 1 , 1 );
+    gtk_grid_attach( GTK_GRID(tex_font_grid) , tex_font_shadow_togglebt[i] , 3 , 0 , 1 , 1 );
+    gtk_grid_attach( GTK_GRID(tex_font_grid) , tex_font_shadow_colorbt[i] , 4 , 0 , 1 , 1 );
+#else
+    chooser_set_aosd_color( GTK_COLOR_BUTTON(tex_font_colorbt[i]) , &cfg->text.fonts_color[i] );
+    chooser_set_aosd_color( GTK_COLOR_BUTTON(tex_font_shadow_colorbt[i]) , &cfg->text.fonts_shadow_color[i] );
+
     gtk_table_attach_defaults( GTK_TABLE(tex_font_grid) , tex_font_label[i] , 0 , 1 , i , i + 1 );
     gtk_table_attach_defaults( GTK_TABLE(tex_font_grid) , tex_font_fontbt[i] , 1 , 2 , i , i + 1 );
     gtk_table_attach_defaults( GTK_TABLE(tex_font_grid) , tex_font_colorbt[i] , 2 , 3 , i , i + 1 );
     gtk_table_attach_defaults( GTK_TABLE(tex_font_grid) , tex_font_shadow_togglebt[i] , 3 , 4 , i , i + 1 );
     gtk_table_attach_defaults( GTK_TABLE(tex_font_grid) , tex_font_shadow_colorbt[i] , 4 , 5 , i , i + 1 );
+#endif
+
     g_object_set_data( G_OBJECT(tex_font_fontbt[i]) , "fontnum" , GINT_TO_POINTER(i) );
     g_object_set_data( G_OBJECT(tex_font_fontbt[i]) , "color" , tex_font_colorbt[i] );
     g_object_set_data( G_OBJECT(tex_font_fontbt[i]) , "use_shadow" , tex_font_shadow_togglebt[i] );
@@ -429,7 +528,12 @@ static void
 aosd_cb_configure_decoration_color_commit ( GtkWidget * colorbt , aosd_cfg_t * cfg )
 {
   aosd_color_t color;
-  chooser_get_aosd_color ((GtkColorButton *) colorbt, & color);
+
+#ifdef USE_GTK3
+  chooser_get_aosd_color( GTK_COLOR_CHOOSER(colorbt), &color );
+#else
+  chooser_get_aosd_color( GTK_COLOR_BUTTON(colorbt), &color );
+#endif
 
   int colnum = GPOINTER_TO_INT( g_object_get_data( G_OBJECT(colorbt) , "colnum" ) );
   cfg->decoration.colors[colnum] = color;
@@ -446,11 +550,11 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
   GtkTreeViewColumn *dec_rstyle_lv_col_desc;
   GtkTreeSelection *dec_rstyle_lv_sel;
   GtkTreeIter iter, iter_sel;
-  GtkWidget *dec_rstyle_hbox;
+  GtkWidget *dec_rstyle_vbox;
   GtkWidget *dec_rstyleopts_frame, *dec_rstyleopts_grid;
   int colors_max_num = 0, i = 0;
 
-  dec_hbox = gtk_hbox_new( false , 4 );
+  dec_hbox = audgui_hbox_new( 4 );
   gtk_container_set_border_width( GTK_CONTAINER(dec_hbox) , 6 );
 
   /* decoration style model
@@ -494,35 +598,42 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
   gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_lv_frame , false , false , 0 );
   aosd_cb_list.append( dec_rstyle_lv , aosd_cb_configure_decoration_style_commit );
 
-  dec_rstyle_hbox = gtk_vbox_new( false , 4 );
-  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_hbox , true , true , 0 );
+  dec_rstyle_vbox = audgui_vbox_new( 4 );
+  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_vbox , true , true , 0 );
 
   /* in colors_max_num now there's the maximum number of colors used by decoration styles */
   dec_rstyleopts_frame = gtk_frame_new( _("Colors") );
-  dec_rstyleopts_grid = gtk_table_new (0, 0, false);
+  dec_rstyleopts_grid = audgui_grid_new();
   gtk_container_set_border_width( GTK_CONTAINER(dec_rstyleopts_grid) , 6 );
-  gtk_table_set_row_spacings( GTK_TABLE(dec_rstyleopts_grid) , 4 );
-  gtk_table_set_col_spacings( GTK_TABLE(dec_rstyleopts_grid) , 8 );
+  audgui_grid_set_row_spacing( dec_rstyleopts_grid , 4 );
+  audgui_grid_set_column_spacing( dec_rstyleopts_grid , 8 );
   gtk_container_add( GTK_CONTAINER(dec_rstyleopts_frame) , dec_rstyleopts_grid );
   for ( i = 0 ; i < colors_max_num ; i++ )
   {
     GtkWidget *hbox, *label;
     char *label_str = nullptr;
-    hbox = gtk_hbox_new( false , 4 );
+    hbox = audgui_hbox_new( 4 );
     label_str = g_strdup_printf( _("Color %i:") , i+1 );
     label = gtk_label_new( label_str );
     g_free( label_str );
 
     GtkWidget * colorbt = gtk_color_button_new ();
-    chooser_set_aosd_color ((GtkColorButton *) colorbt, & cfg->decoration.colors[i]);
 
     gtk_box_pack_start( GTK_BOX(hbox) , label , false , false , 0 );
     gtk_box_pack_start( GTK_BOX(hbox) , colorbt , false , false , 0 );
-    gtk_table_attach_defaults( GTK_TABLE(dec_rstyleopts_grid) , hbox , (i % 3) , (i % 3) + 1, (i / 3) , (i / 3) + 1);
+
+#ifdef USE_GTK3
+    chooser_set_aosd_color( GTK_COLOR_CHOOSER(colorbt) , &cfg->decoration.colors[i] );
+    gtk_grid_attach( GTK_GRID(dec_rstyleopts_grid) , hbox , (i % 3) , (i / 3) , 1 , 1 );
+#else
+    chooser_set_aosd_color( GTK_COLOR_BUTTON(colorbt) , &cfg->decoration.colors[i] );
+    gtk_table_attach_defaults( GTK_TABLE(dec_rstyleopts_grid) , hbox , (i % 3) , (i % 3) + 1, (i / 3) , (i / 3) + 1 );
+#endif
+
     g_object_set_data( G_OBJECT(colorbt) , "colnum" , GINT_TO_POINTER(i) );
     aosd_cb_list.append( colorbt , aosd_cb_configure_decoration_color_commit );
   }
-  gtk_box_pack_start( GTK_BOX(dec_rstyle_hbox) , dec_rstyleopts_frame , false , false , 0 );
+  gtk_box_pack_start( GTK_BOX(dec_rstyle_vbox) , dec_rstyleopts_frame , false , false , 0 );
 
   return dec_hbox;
 }
@@ -572,7 +683,7 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
   gtk_notebook_set_show_tabs( GTK_NOTEBOOK(tri_event_nb) , false );
   gtk_notebook_set_show_border( GTK_NOTEBOOK(tri_event_nb) , false );
 
-  tri_hbox = gtk_hbox_new( false , 4 );
+  tri_hbox = audgui_hbox_new( 4 );
   gtk_container_set_border_width( GTK_CONTAINER(tri_hbox) , 6 );
 
   /* trigger model
@@ -590,19 +701,23 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
     gtk_list_store_set( tri_event_store , &iter ,
       0 , _(aosd_trigger_get_name( i )) ,
       1 , i , 2 , i , -1 );
-    vbox = gtk_vbox_new( false , 0 );
+    vbox = audgui_vbox_new( 0 );
     gtk_container_set_border_width( GTK_CONTAINER(vbox) , 6 );
     label = gtk_label_new( _(aosd_trigger_get_desc( i )) );
     gtk_label_set_line_wrap( GTK_LABEL(label) , true );
     gtk_label_set_max_width_chars( GTK_LABEL(label), 40 );
+#ifdef USE_GTK3
+    gtk_widget_set_halign( label , GTK_ALIGN_START );
+#else
     gtk_misc_set_alignment( GTK_MISC(label) , 0.0 , 0.0 );
+#endif
     checkbt = gtk_check_button_new_with_label( _("Enable trigger") );
     if ( cfg->trigger.enabled[i] )
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , true );
     else
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , false );
     gtk_box_pack_start( GTK_BOX(vbox) , checkbt , false , false , 0 );
-    gtk_box_pack_start( GTK_BOX(vbox) , gtk_hseparator_new() , false , false , 4 );
+    gtk_box_pack_start( GTK_BOX(vbox) , audgui_separator_new( GTK_ORIENTATION_HORIZONTAL ) , false , false , 4 );
     gtk_box_pack_start( GTK_BOX(vbox) , label , false , false , 0 );
     frame = gtk_frame_new( nullptr );
     gtk_container_add( GTK_CONTAINER(frame) , vbox );
@@ -698,10 +813,10 @@ aosd_ui_configure_misc ( aosd_cfg_t * cfg )
   GtkWidget *mis_transp_status_frame, *mis_transp_status_hbox;
   GtkWidget *mis_transp_status_img, *mis_transp_status_label;
 
-  mis_vbox = gtk_vbox_new( false , 0 );
+  mis_vbox = audgui_vbox_new( 0 );
   gtk_container_set_border_width( GTK_CONTAINER(mis_vbox) , 6 );
 
-  mis_transp_vbox = gtk_vbox_new( false , 0 );
+  mis_transp_vbox = audgui_vbox_new( 0 );
   mis_transp_frame = gtk_frame_new( _("Transparency") );
   gtk_container_set_border_width( GTK_CONTAINER(mis_transp_vbox) , 6 );
   gtk_container_add( GTK_CONTAINER(mis_transp_frame) , mis_transp_vbox );
@@ -718,16 +833,22 @@ aosd_ui_configure_misc ( aosd_cfg_t * cfg )
   gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_fake_rbt , true , true , 0 );
   gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_real_rbt , true , true , 0 );
 
-  mis_transp_status_hbox = gtk_hbox_new( false , 4 );
+  mis_transp_status_hbox = audgui_hbox_new( 4 );
   mis_transp_status_frame = gtk_frame_new( nullptr );
   gtk_container_set_border_width( GTK_CONTAINER(mis_transp_status_hbox) , 3 );
   gtk_container_add( GTK_CONTAINER(mis_transp_status_frame) , mis_transp_status_hbox );
   gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_status_frame , true , true , 0 );
 
   mis_transp_status_img = gtk_image_new();
-  gtk_misc_set_alignment( GTK_MISC(mis_transp_status_img) , 0.5 , 0 );
   mis_transp_status_label = gtk_label_new( "" );
+
+#ifdef USE_GTK3
+  gtk_widget_set_halign( mis_transp_status_label , GTK_ALIGN_START );
+#else
+  gtk_misc_set_alignment( GTK_MISC(mis_transp_status_img) , 0.5 , 0 );
   gtk_misc_set_alignment( GTK_MISC(mis_transp_status_label) , 0 , 0.5 );
+#endif
+
   gtk_label_set_line_wrap( GTK_LABEL(mis_transp_status_label) , true );
   gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_img , false , false , 0 );
   gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_label , true , true , 0 );
