@@ -144,7 +144,6 @@ static int block_delay = 0;
 static struct timeval block_time = {0, 0};
 
 static AudioComponent output_comp = nullptr;
-// static AudioComponentInstance output_instance = nullptr;
 static AudioUnit output_instance = nullptr;
 
 static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -223,11 +222,11 @@ bool CoreAudioPlugin::init ()
 
     AudioObjectPropertyAddress prop = { kAudioHardwarePropertyDefaultOutputDevice,
                                         kAudioObjectPropertyScopeGlobal,
-                                        kAudioObjectPropertyElementMaster };
+                                        kAudioObjectPropertyElementMain };
 
     UInt32 size = sizeof(AudioObjectID);
     AudioObjectID defaultOutputDeviceID;
-    err = AudioObjectGetPropertyData(kAudioObjectSystemObject, &prop, 0, NULL, &size, &defaultOutputDeviceID);
+    err = AudioObjectGetPropertyData(kAudioObjectSystemObject, &prop, 0, nullptr, &size, &defaultOutputDeviceID);
     if (err == noErr)
     {
         if (coreAudioDevice) {
@@ -237,7 +236,7 @@ bool CoreAudioPlugin::init ()
             coreAudioDevice = nullptr;
         }
         coreAudioDevice = AudioDevice::GetDevice(defaultOutputDeviceID, false, coreAudioDevice, true);
-        if (coreAudioDevice != NULL)
+        if (coreAudioDevice != nullptr)
         {
             coreAudioDevice->installDefaultDeviceChangeHandler(callDefaultDeviceChangeHandler, static_cast<void*>(this));
             coreAudioDevice->setDefaultDevice(true);
@@ -458,6 +457,8 @@ bool CoreAudioPlugin::open_audio (int format, int rate_, int chan_, String & err
         return 0;
     }
 
+    set_volume (get_volume ());
+
     bool exclusive = aud_get_bool ("coreaudio", "exclusive_mode");
     if (exclusive)
     {
@@ -467,7 +468,7 @@ bool CoreAudioPlugin::open_audio (int format, int rate_, int chan_, String & err
 
         prop.mSelector = kAudioDevicePropertyHogMode;
         prop.mScope    = kAudioObjectPropertyScopeGlobal;
-        prop.mElement  = kAudioObjectPropertyElementMaster;
+        prop.mElement  = kAudioObjectPropertyElementMain;
 
         OSStatus result = AudioObjectSetPropertyData (kAudioObjectSystemObject, & prop, 0, nullptr, sizeof hog_mode, & hog_mode);
         if (result != noErr)
@@ -515,7 +516,7 @@ void CoreAudioPlugin::close_audio ()
 
         prop.mSelector = kAudioDevicePropertyHogMode;
         prop.mScope    = kAudioObjectPropertyScopeGlobal;
-        prop.mElement  = kAudioObjectPropertyElementMaster;
+        prop.mElement  = kAudioObjectPropertyElementMain;
 
         OSStatus err = AudioObjectSetPropertyData (kAudioObjectSystemObject, & prop, 0, nullptr, sizeof hog_mode, & hog_mode);
         if (err != noErr)
