@@ -23,6 +23,7 @@
 
 #include "ffaudio-stdinc.h"
 
+#include <limits.h>
 #include <pthread.h>
 
 #include <audacious/audtag.h>
@@ -88,6 +89,12 @@ struct ScopedContext
 #else
         ptr = cinfo.stream->codec;
 #endif
+
+#if CHECK_LIBAVCODEC_VERSION(58, 9, 100)
+        ptr->pkt_timebase = cinfo.stream->time_base;
+#else
+        av_codec_set_pkt_timebase (ptr, cinfo.stream->time_base);
+#endif
     }
 
 #ifdef ALLOC_CONTEXT
@@ -444,8 +451,10 @@ bool FFaudio::read_tag (const char * filename, VFSFile & file, Tuple & tuple, In
     if (! find_codec (ic.get (), & cinfo))
         return false;
 
-    tuple.set_int (Tuple::Length, ic->duration / 1000);
-    tuple.set_int (Tuple::Bitrate, ic->bit_rate / 1000);
+    if (ic->duration > 0 && ic->duration / 1000 <= INT_MAX)
+        tuple.set_int (Tuple::Length, ic->duration / 1000);
+    if (ic->bit_rate > 0 && ic->bit_rate / 1000 <= INT_MAX)
+        tuple.set_int (Tuple::Bitrate, ic->bit_rate / 1000);
 
     if (cinfo.codec->long_name)
         tuple.set_str (Tuple::Codec, cinfo.codec->long_name);
@@ -529,9 +538,15 @@ bool FFaudio::play (const char * filename, VFSFile & file)
     if (! convert_format (context->sample_fmt, out_fmt, planar))
         return false;
 
+#if CHECK_LIBAVCODEC_VERSION(59, 37, 100)
+    int channels = context->ch_layout.nb_channels;
+#else
+    int channels = context->channels;
+#endif
+
     /* Open audio output */
     set_stream_bitrate(ic->bit_rate);
-    open_audio(out_fmt, context->sample_rate, context->channels);
+    open_audio(out_fmt, context->sample_rate, channels);
 
     int errcount = 0;
     bool eof = false;
@@ -612,7 +627,7 @@ bool FFaudio::play (const char * filename, VFSFile & file)
             }
 #endif
 
-            int size = FMT_SIZEOF (out_fmt) * context->channels * frame->nb_samples;
+            int size = FMT_SIZEOF (out_fmt) * channels * frame->nb_samples;
 
             if (planar)
             {
@@ -620,7 +635,7 @@ bool FFaudio::play (const char * filename, VFSFile & file)
                     buf.resize (size);
 
                 audio_interlace ((const void * *) frame->data, out_fmt,
-                 context->channels, buf.begin (), frame->nb_samples);
+                 channels, buf.begin (), frame->nb_samples);
                 write_audio (buf.begin (), size);
             }
             else
@@ -695,5 +710,6 @@ const char * const FFaudio::exts[] = {
 const char * const FFaudio::mimes[] = {
     "application/ogg",
     "audio/mp4",
+    "audio/ogg",
     nullptr
 };
