@@ -45,6 +45,8 @@ public:
         CustomTitle,
         Bitrate,
         Comment,
+        Publisher,
+        CatalogNum,
         n_cols
     };
 
