@@ -49,9 +49,7 @@ class TimeSliderStyle : public QProxyStyle
 public:
     TimeSliderStyle()
     {
-        // detect and respond to application-wide style change
-        connect(qApp->style(), &QObject::destroyed, this,
-                &TimeSliderStyle::resetBaseStyle);
+        audqt::setup_proxy_style(this);
     }
 
     int styleHint(QStyle::StyleHint hint, const QStyleOption * option = nullptr,
@@ -66,21 +64,17 @@ public:
 
         return styleHint;
     }
-
-private:
-    void resetBaseStyle()
-    {
-        setBaseStyle(nullptr);
-        connect(qApp->style(), &QObject::destroyed, this,
-                &TimeSliderStyle::resetBaseStyle);
-    }
 };
 
 TimeSlider::TimeSlider(QWidget * parent)
     : QSlider(Qt::Horizontal, parent), m_label(new TimeSliderLabel(parent))
 {
     setFocusPolicy(Qt::NoFocus);
+#ifdef Q_OS_MAC
+    setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
+#else
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
+#endif
 
     auto style = new TimeSliderStyle;
     style->setParent(this);
@@ -96,6 +90,19 @@ TimeSlider::TimeSlider(QWidget * parent)
     start_stop();
 }
 
+void TimeSlider::wheelEvent(QWheelEvent *event)
+{
+    m_scroll_delta += event->angleDelta().y();
+
+    /* we want discrete steps here */
+    int steps = m_scroll_delta / 120;
+    if (steps != 0)
+    {
+        m_scroll_delta -= 120 * steps;
+        aud_drct_seek(aud_drct_get_time() + steps * aud_get_int("step_size") * 1000);
+    }
+}
+
 void TimeSlider::set_label(int time, int length)
 {
     QString text;
