@@ -219,7 +219,7 @@ bool SndfilePlugin::read_tag (const char * filename, VFSFile & file, Tuple & tup
             format = "Core Audio File";
             break;
         default:
-            format = "Unknown sndfile";
+            format = nullptr;
     }
 
     switch (sfinfo.format & SF_FORMAT_SUBMASK)
@@ -294,6 +294,15 @@ bool SndfilePlugin::read_tag (const char * filename, VFSFile & file, Tuple & tup
             subformat = nullptr;
     }
 
+    if (format == nullptr)
+    {
+        SF_FORMAT_INFO info = {.format = sfinfo.format & SF_FORMAT_SUBMASK};
+        if (sf_command (sndfile, SFC_GET_FORMAT_INFO, & info, sizeof (info)) == 0)
+            format = info.name;
+        else
+            format = "Unknown format";
+    }
+
     if (subformat != nullptr)
         tuple.set_format (str_printf ("%s (%s)", format, subformat),
          sfinfo.channels, sfinfo.samplerate, 0);
